@@ -21,6 +21,6 @@ from . import azt_logger as logger
 from . import azt_dataclass as datacls
 
 from .azt_socket_zmq import Socket as ZmqSocketCls
-from .azt_socket import Socket as SocketCls
+from .qujam_socket import QujamSocket, HeaderRecvPolicy, HeaderSendPolicy
 from .azt_errors import *
 from .utils import *
