@@ -45,6 +45,19 @@ def debug_calc_time(func):
     return wrapper
 
 
+def _make_round_f(rn=None):
+    if rn is None:
+        def tmpf1(v):
+            return v
+
+        return tmpf1
+
+    def tmpf2(v):
+        return round(v, rn) if (type(v) == float) else v
+
+    return tmpf2
+
+
 def aztdataclass(protocls,
                  price_dec: str = None, amount_dec: str = None,
                  adj_price: list = None, adj_amount: list = None,
@@ -103,8 +116,10 @@ def aztdataclass(protocls,
     price_decimal_pow = 10 ** price_decimal_place
     amount_decimal_pow = 10 ** amount_decimal_place
 
-    @debug_calc_time
-    def func_proto2py(cls, proto):
+    # @debug_calc_time
+    def func_proto2py(cls, proto, rn=None):
+        # _round_f = (lambda x: x) if rn is None else (lambda x: round(x, rn) if type(x) is float else x)
+        _round_f = _make_round_f(rn)
         params = dict()
 
         cls_attrs = cls.__annotations__
@@ -117,10 +132,11 @@ def aztdataclass(protocls,
         for normal_attr_name in normal_attrs:
             normal_atrr_cls = cls_attrs[normal_attr_name]
             if hasattr(normal_atrr_cls, "__proto2py__"):
-                params[normal_attr_name] = normal_atrr_cls.__proto2py__(getattr(proto, proto_attrs[normal_attr_name]))
+                params[normal_attr_name] = normal_atrr_cls.__proto2py__(getattr(proto, proto_attrs[normal_attr_name]),
+                                                                        rn)
             else:
-                params[normal_attr_name] = getattr(proto, normal_attr_name)
-        # 2 需要处理的属性
+                params[normal_attr_name] = _round_f(getattr(proto, normal_attr_name))
+                # 2 需要处理的属性
         # 2.1 需要由int转float的价格
         if price_dec is not None:
             p_d = price_decimal_pow
@@ -176,10 +192,10 @@ def aztdataclass(protocls,
                 if type(repeat_attr_cls) is list:
                     inner_type = repeat_attr_cls[0]
                     if hasattr(inner_type, "__proto2py__"):
-                        params[repeat_attr_name] = [inner_type.__proto2py__(inner_proto) for inner_proto in
+                        params[repeat_attr_name] = [inner_type.__proto2py__(inner_proto, rn) for inner_proto in
                                                     getattr(proto, proto_attr_name)]
                     else:
-                        params[repeat_attr_name] = list(getattr(proto, proto_attr_name))
+                        params[repeat_attr_name] = list(map(_round_f, getattr(proto, proto_attr_name)))
                 else:
                     raise azt_errors.ListTypeError
 
@@ -191,10 +207,11 @@ def aztdataclass(protocls,
                 if type(map_attr_cls) is dict:
                     val_atrr_cls = list(map_attr_cls.values())[0]
                     if hasattr(val_atrr_cls, "__proto2py__"):
-                        params[map_attr_name] = {map_idx: val_atrr_cls.__proto2py__(proto_map_val[map_idx])
+                        params[map_attr_name] = {map_idx: val_atrr_cls.__proto2py__(proto_map_val[map_idx], rn)
                                                  for map_idx in proto_map_val}
                     else:
-                        params[map_attr_name] = dict(proto_map_val)
+                        # params[map_attr_name] = dict(proto_map_val)
+                        params[map_attr_name] = {_k: _round_f(_v) for _k, _v in proto_map_val.items()}
                 else:
                     raise azt_errors.DictTypeError
         for any_attr_name in adj_any_attrs:
@@ -204,7 +221,7 @@ def aztdataclass(protocls,
                 if hasattr(any_attr_type, "__protocls__"):
                     any_attr_proto = any_attr_type.__protocls__()
                     getattr(proto, proto_attr_name).Unpack(any_attr_proto)
-                    params[any_attr_name] = any_attr_type.__proto2py__(any_attr_proto)
+                    params[any_attr_name] = any_attr_type.__proto2py__(any_attr_proto, rn)
 
         # 时间格式转换
         for time_attr_name in adj_time_attrs:
@@ -229,7 +246,7 @@ def aztdataclass(protocls,
                     params[time_attr_name] = time_transformed
         return cls(**params)
 
-    @debug_calc_time
+    # @debug_calc_time
     def func_py2proto(self):
         proto = protocls()
         cls_attrs = self.__annotations__
