@@ -17,5 +17,5 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
 
-from .trade_api import TradeApi, TradeSpi
-from .quote_api import QuoteApi, QuoteSpi
+from .trade_api import AztTradeApi, AztTradeSpi
+from .quote_api import AztQuoteApi, AztQuoteSpi
