@@ -16,26 +16,28 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
+from typing import List, Union
+
 from ._quote_api_base import *
 
 
 class AztQuoteApi(QuoteApiBase):
-    def Subscribe(self, codes: list[str], sync=False, timeout=None):
-        return self._subscribe(codes, sync=sync, timeout=timeout)
+    def Subscribe(self, codes: Union[str, List[str]]):
+        return self._subscribe(codes)
 
-    def Unsubscribe(self, codes, sync=False, timeout=None):
-        return self._unsubscribe(codes, sync=sync, timeout=timeout)
+    def Unsubscribe(self, codes: Union[str, List[str]]):
+        return self._unsubscribe(codes)
 
-    def Start(self, server_addr: str, spi=None, timeout=None):
+    def Start(self, ip: str, port: int, spi=None, timeout=None, set_heart_beat=False):
         if spi:
-            if spi.__class__ is type:
+            if isinstance(spi, type):
                 spi = spi()
-            if getattr(self.spi, "api", None) is None:
-                setattr(self.spi, "api", self)
-        return self._start(server_addr, spi, timeout)
+            if not getattr(spi, "api", None):
+                setattr(spi, "api", self)
+        return self._start(ip, port, spi, timeout, set_heart_beat)
 
     def Stop(self):
         return self._stop()  # 正常stop返回None
 
-    def Join(self, timeout=None):
+    def Join(self, timeout: int = None):
         self._join(timeout=timeout)
