@@ -16,5 +16,5 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
-from .trade_api import TradeApi
-from .trade_spi import TradeSpi
+from .trade_api import AztTradeApi
+from .trade_spi import AztTradeSpi
