@@ -17,5 +17,6 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
 
-from . import trade_api_struct
-from . import trade_spi_struct
+from .trade_spi_struct import *
+from .trade_api_struct import *
+from .quote_spi_struct import *
