@@ -21,7 +21,7 @@ import datetime
 
 from AztVe.common.azt_dataclass import aztdataclass
 from .trade_api_struct import PlaceOrder
-from ..protobufs import Trade_Message_pb2 as proto
+from ..protos import Trade_Message_pb2 as proto
 
 
 # 用户注册回复信息
